# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.distribution_update_parameters import DistributionUpdateParameters  # noqa: E501
from phrase_api.rest import ApiException

class TestDistributionUpdateParameters(unittest.TestCase):
    """DistributionUpdateParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DistributionUpdateParameters
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.distribution_update_parameters.DistributionUpdateParameters()  # noqa: E501
        if include_optional :
            return DistributionUpdateParameters(
                name = 'My Android Distribution', 
                project_id = 'abcd1234abcd1234abcd1234', 
                platforms = ["android","ios"], 
                locale_ids = ["abcd1234cdef1234abcd1234cdef1234","fff565db236400772368235db2c6117e"], 
                format_options = {xml:{enclose_in_cdata:'1'}}, 
                fallback_locales_enabled = True, 
                fallback_to_non_regional_locale = True, 
                fallback_to_default_locale = True, 
                use_last_reviewed_version = True
            )
        else :
            return DistributionUpdateParameters(
        )

    def testDistributionUpdateParameters(self):
        """Test DistributionUpdateParameters"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
