# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.jobs_api import JobsApi  # noqa: E501
from phrase_api.rest import ApiException


class TestJobsApi(unittest.TestCase):
    """JobsApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.jobs_api.JobsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_job_complete(self):
        """Test case for job_complete

        Complete a job  # noqa: E501
        """
        pass

    def test_job_create(self):
        """Test case for job_create

        Create a job  # noqa: E501
        """
        pass

    def test_job_delete(self):
        """Test case for job_delete

        Delete a job  # noqa: E501
        """
        pass

    def test_job_keys_create(self):
        """Test case for job_keys_create

        Add keys to job  # noqa: E501
        """
        pass

    def test_job_keys_delete(self):
        """Test case for job_keys_delete

        Remove keys from job  # noqa: E501
        """
        pass

    def test_job_lock(self):
        """Test case for job_lock

        Lock a job  # noqa: E501
        """
        pass

    def test_job_reopen(self):
        """Test case for job_reopen

        Reopen a job  # noqa: E501
        """
        pass

    def test_job_show(self):
        """Test case for job_show

        Get a single job  # noqa: E501
        """
        pass

    def test_job_start(self):
        """Test case for job_start

        Start a job  # noqa: E501
        """
        pass

    def test_job_unlock(self):
        """Test case for job_unlock

        Unlock a job  # noqa: E501
        """
        pass

    def test_job_update(self):
        """Test case for job_update

        Update a job  # noqa: E501
        """
        pass

    def test_jobs_by_account(self):
        """Test case for jobs_by_account

        List account jobs  # noqa: E501
        """
        pass

    def test_jobs_list(self):
        """Test case for jobs_list

        List jobs  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
