# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.orders_api import OrdersApi  # noqa: E501
from phrase_api.rest import ApiException


class TestOrdersApi(unittest.TestCase):
    """OrdersApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.orders_api.OrdersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_order_confirm(self):
        """Test case for order_confirm

        Confirm an order  # noqa: E501
        """
        pass

    def test_order_create(self):
        """Test case for order_create

        Create a new order  # noqa: E501
        """
        pass

    def test_order_delete(self):
        """Test case for order_delete

        Cancel an order  # noqa: E501
        """
        pass

    def test_order_show(self):
        """Test case for order_show

        Get a single order  # noqa: E501
        """
        pass

    def test_orders_list(self):
        """Test case for orders_list

        List orders  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
