# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.releases_api import ReleasesApi  # noqa: E501
from phrase_api.rest import ApiException


class TestReleasesApi(unittest.TestCase):
    """ReleasesApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.releases_api.ReleasesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_release_create(self):
        """Test case for release_create

        Create a release  # noqa: E501
        """
        pass

    def test_release_delete(self):
        """Test case for release_delete

        Delete a release  # noqa: E501
        """
        pass

    def test_release_publish(self):
        """Test case for release_publish

        Publish a release  # noqa: E501
        """
        pass

    def test_release_show(self):
        """Test case for release_show

        Get a single release  # noqa: E501
        """
        pass

    def test_release_update(self):
        """Test case for release_update

        Update a release  # noqa: E501
        """
        pass

    def test_releases_list(self):
        """Test case for releases_list

        List releases  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
