# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.glossary_terms_api import GlossaryTermsApi  # noqa: E501
from phrase_api.rest import ApiException


class TestGlossaryTermsApi(unittest.TestCase):
    """GlossaryTermsApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.glossary_terms_api.GlossaryTermsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_glossary_term_create(self):
        """Test case for glossary_term_create

        Create a term  # noqa: E501
        """
        pass

    def test_glossary_term_delete(self):
        """Test case for glossary_term_delete

        Delete a term  # noqa: E501
        """
        pass

    def test_glossary_term_show(self):
        """Test case for glossary_term_show

        Get a single term  # noqa: E501
        """
        pass

    def test_glossary_term_update(self):
        """Test case for glossary_term_update

        Update a term  # noqa: E501
        """
        pass

    def test_glossary_terms_list(self):
        """Test case for glossary_terms_list

        List terms  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
