# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.webhooks_api import WebhooksApi  # noqa: E501
from phrase_api.rest import ApiException


class TestWebhooksApi(unittest.TestCase):
    """WebhooksApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.webhooks_api.WebhooksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_webhook_create(self):
        """Test case for webhook_create

        Create a webhook  # noqa: E501
        """
        pass

    def test_webhook_delete(self):
        """Test case for webhook_delete

        Delete a webhook  # noqa: E501
        """
        pass

    def test_webhook_show(self):
        """Test case for webhook_show

        Get a single webhook  # noqa: E501
        """
        pass

    def test_webhook_test(self):
        """Test case for webhook_test

        Test a webhook  # noqa: E501
        """
        pass

    def test_webhook_update(self):
        """Test case for webhook_update

        Update a webhook  # noqa: E501
        """
        pass

    def test_webhooks_list(self):
        """Test case for webhooks_list

        List webhooks  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
