# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.translation_order import TranslationOrder  # noqa: E501
from phrase_api.rest import ApiException

class TestTranslationOrder(unittest.TestCase):
    """TranslationOrder unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TranslationOrder
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.translation_order.TranslationOrder()  # noqa: E501
        if include_optional :
            return TranslationOrder(
                id = '0', 
                name = '0', 
                lsp = '0', 
                amount_in_cents = 56, 
                currency = '0', 
                message = '0', 
                state = '0', 
                translation_type = '0', 
                progress_percent = 56, 
                source_locale = {"id":"abcd1234cdef1234abcd1234cdef1234","name":"English","code":"en-GB"}, 
                target_locales = [
                    {"id":"abcd1234cdef1234abcd1234cdef1234","name":"English","code":"en-GB"}
                    ], 
                tag = '0', 
                styleguide = {"id":"abcd1234cdef1234abcd1234cdef1234","title":"My Style Guide"}, 
                unverify_translations_upon_delivery = True, 
                quality = True, 
                priority = True, 
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else :
            return TranslationOrder(
        )

    def testTranslationOrder(self):
        """Test TranslationOrder"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
