# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.webhook_deliveries_api import WebhookDeliveriesApi  # noqa: E501
from phrase_api.rest import ApiException


class TestWebhookDeliveriesApi(unittest.TestCase):
    """WebhookDeliveriesApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.webhook_deliveries_api.WebhookDeliveriesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_webhook_deliveries_list(self):
        """Test case for webhook_deliveries_list

        List webhook deliveries  # noqa: E501
        """
        pass

    def test_webhook_deliveries_redeliver(self):
        """Test case for webhook_deliveries_redeliver

        Redeliver a single webhook delivery  # noqa: E501
        """
        pass

    def test_webhook_deliveries_show(self):
        """Test case for webhook_deliveries_show

        Get a single webhook delivery  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
