# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.style_guides_api import StyleGuidesApi  # noqa: E501
from phrase_api.rest import ApiException


class TestStyleGuidesApi(unittest.TestCase):
    """StyleGuidesApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.style_guides_api.StyleGuidesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_styleguide_create(self):
        """Test case for styleguide_create

        Create a style guide  # noqa: E501
        """
        pass

    def test_styleguide_delete(self):
        """Test case for styleguide_delete

        Delete a style guide  # noqa: E501
        """
        pass

    def test_styleguide_show(self):
        """Test case for styleguide_show

        Get a single style guide  # noqa: E501
        """
        pass

    def test_styleguide_update(self):
        """Test case for styleguide_update

        Update a style guide  # noqa: E501
        """
        pass

    def test_styleguides_list(self):
        """Test case for styleguides_list

        List style guides  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
