# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.glossary_term_translations_api import GlossaryTermTranslationsApi  # noqa: E501
from phrase_api.rest import ApiException


class TestGlossaryTermTranslationsApi(unittest.TestCase):
    """GlossaryTermTranslationsApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.glossary_term_translations_api.GlossaryTermTranslationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_glossary_term_translation_create(self):
        """Test case for glossary_term_translation_create

        Create a translation for a term  # noqa: E501
        """
        pass

    def test_glossary_term_translation_delete(self):
        """Test case for glossary_term_translation_delete

        Delete a translation for a term  # noqa: E501
        """
        pass

    def test_glossary_term_translation_update(self):
        """Test case for glossary_term_translation_update

        Update a translation for a term  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
