# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.screenshot_markers_api import ScreenshotMarkersApi  # noqa: E501
from phrase_api.rest import ApiException


class TestScreenshotMarkersApi(unittest.TestCase):
    """ScreenshotMarkersApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.screenshot_markers_api.ScreenshotMarkersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_screenshot_marker_create(self):
        """Test case for screenshot_marker_create

        Create a screenshot marker  # noqa: E501
        """
        pass

    def test_screenshot_marker_delete(self):
        """Test case for screenshot_marker_delete

        Delete a screenshot marker  # noqa: E501
        """
        pass

    def test_screenshot_marker_show(self):
        """Test case for screenshot_marker_show

        Get a single screenshot marker  # noqa: E501
        """
        pass

    def test_screenshot_marker_update(self):
        """Test case for screenshot_marker_update

        Update a screenshot marker  # noqa: E501
        """
        pass

    def test_screenshot_markers_list(self):
        """Test case for screenshot_markers_list

        List screenshot markers  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
