# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.comments_api import CommentsApi  # noqa: E501
from phrase_api.rest import ApiException


class TestCommentsApi(unittest.TestCase):
    """CommentsApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.comments_api.CommentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_comment_create(self):
        """Test case for comment_create

        Create a comment  # noqa: E501
        """
        pass

    def test_comment_delete(self):
        """Test case for comment_delete

        Delete a comment  # noqa: E501
        """
        pass

    def test_comment_mark_check(self):
        """Test case for comment_mark_check

        Check if comment is read  # noqa: E501
        """
        pass

    def test_comment_mark_read(self):
        """Test case for comment_mark_read

        Mark a comment as read  # noqa: E501
        """
        pass

    def test_comment_mark_unread(self):
        """Test case for comment_mark_unread

        Mark a comment as unread  # noqa: E501
        """
        pass

    def test_comment_show(self):
        """Test case for comment_show

        Get a single comment  # noqa: E501
        """
        pass

    def test_comment_update(self):
        """Test case for comment_update

        Update a comment  # noqa: E501
        """
        pass

    def test_comments_list(self):
        """Test case for comments_list

        List comments  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
