# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.keys_api import KeysApi  # noqa: E501
from phrase_api.rest import ApiException


class TestKeysApi(unittest.TestCase):
    """KeysApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.keys_api.KeysApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_key_create(self):
        """Test case for key_create

        Create a key  # noqa: E501
        """
        pass

    def test_key_delete(self):
        """Test case for key_delete

        Delete a key  # noqa: E501
        """
        pass

    def test_key_show(self):
        """Test case for key_show

        Get a single key  # noqa: E501
        """
        pass

    def test_key_update(self):
        """Test case for key_update

        Update a key  # noqa: E501
        """
        pass

    def test_keys_delete_collection(self):
        """Test case for keys_delete_collection

        Delete collection of keys  # noqa: E501
        """
        pass

    def test_keys_exclude(self):
        """Test case for keys_exclude

        Exclude a locale on a collection of keys  # noqa: E501
        """
        pass

    def test_keys_include(self):
        """Test case for keys_include

        Include a locale on a collection of keys  # noqa: E501
        """
        pass

    def test_keys_list(self):
        """Test case for keys_list

        List keys  # noqa: E501
        """
        pass

    def test_keys_search(self):
        """Test case for keys_search

        Search keys  # noqa: E501
        """
        pass

    def test_keys_tag(self):
        """Test case for keys_tag

        Add tags to collection of keys  # noqa: E501
        """
        pass

    def test_keys_untag(self):
        """Test case for keys_untag

        Remove tags from collection of keys  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
