# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.members_api import MembersApi  # noqa: E501
from phrase_api.rest import ApiException


class TestMembersApi(unittest.TestCase):
    """MembersApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.members_api.MembersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_member_delete(self):
        """Test case for member_delete

        Remove a user from the account  # noqa: E501
        """
        pass

    def test_member_show(self):
        """Test case for member_show

        Get single member  # noqa: E501
        """
        pass

    def test_member_update(self):
        """Test case for member_update

        Update a member  # noqa: E501
        """
        pass

    def test_member_update_settings(self):
        """Test case for member_update_settings

        Update a member's project settings  # noqa: E501
        """
        pass

    def test_members_list(self):
        """Test case for members_list

        List members  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
