# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.git_lab_sync_api import GitLabSyncApi  # noqa: E501
from phrase_api.rest import ApiException


class TestGitLabSyncApi(unittest.TestCase):
    """GitLabSyncApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.git_lab_sync_api.GitLabSyncApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_gitlab_sync_delete(self):
        """Test case for gitlab_sync_delete

        Delete single Sync Setting  # noqa: E501
        """
        pass

    def test_gitlab_sync_export(self):
        """Test case for gitlab_sync_export

        Export from Phrase Strings to GitLab  # noqa: E501
        """
        pass

    def test_gitlab_sync_history(self):
        """Test case for gitlab_sync_history

        History of single Sync Setting  # noqa: E501
        """
        pass

    def test_gitlab_sync_import(self):
        """Test case for gitlab_sync_import

        Import from GitLab to Phrase  # noqa: E501
        """
        pass

    def test_gitlab_sync_list(self):
        """Test case for gitlab_sync_list

        List GitLab syncs  # noqa: E501
        """
        pass

    def test_gitlab_sync_show(self):
        """Test case for gitlab_sync_show

        Get single Sync Setting  # noqa: E501
        """
        pass

    def test_gitlab_sync_update(self):
        """Test case for gitlab_sync_update

        Update single Sync Setting  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
