# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.member_project_detail import MemberProjectDetail  # noqa: E501
from phrase_api.rest import ApiException

class TestMemberProjectDetail(unittest.TestCase):
    """MemberProjectDetail unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MemberProjectDetail
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.member_project_detail.MemberProjectDetail()  # noqa: E501
        if include_optional :
            return MemberProjectDetail(
                id = '0', 
                email = '0', 
                username = '0', 
                role = '0', 
                projects = [
                    null
                    ], 
                permissions = None, 
                locale_ids = [
                    '0'
                    ], 
                default_locale_codes = [
                    '0'
                    ], 
                spaces = [
                    phrase_api.models.member_spaces.member_spaces(
                        id = '0', 
                        name = '0', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        projects_count = 56, )
                    ], 
                project_roles = [
                    phrase_api.models.member_project_detail_project_roles.member_project_detail_project_roles(
                        project_id = '0', 
                        role = '0', )
                    ]
            )
        else :
            return MemberProjectDetail(
        )

    def testMemberProjectDetail(self):
        """Test MemberProjectDetail"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
